==> bindings-java-1.9.0-sources.jar: com/daml/ledger/api/v1/LedgerConfigurationServiceGrpc.java <==
package com.daml.ledger.api.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 * <pre>
 * LedgerConfigurationService allows clients to subscribe to changes of the ledger configuration.
 * </pre>
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler",
    comments = "Source: com/daml/ledger/api/v1/ledger_configuration_service.proto")
public final class LedgerConfigurationServiceGrpc {

  private LedgerConfigurationServiceGrpc() {}

  public static final String SERVICE_NAME = "com.daml.ledger.api.v1.LedgerConfigurationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest,
      com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> getGetLedgerConfigurationMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetLedgerConfiguration",
      requestType = com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest.class,
      responseType = com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
  public static io.grpc.MethodDescriptor<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest,
      com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> getGetLedgerConfigurationMethod() {
    io.grpc.MethodDescriptor<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest, com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> getGetLedgerConfigurationMethod;
    if ((getGetLedgerConfigurationMethod = LedgerConfigurationServiceGrpc.getGetLedgerConfigurationMethod) == null) {
      synchronized (LedgerConfigurationServiceGrpc.class) {
        if ((getGetLedgerConfigurationMethod = LedgerConfigurationServiceGrpc.getGetLedgerConfigurationMethod) == null) {
          LedgerConfigurationServiceGrpc.getGetLedgerConfigurationMethod = getGetLedgerConfigurationMethod = 
              io.grpc.MethodDescriptor.<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest, com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
              .setFullMethodName(generateFullMethodName(
                  "com.daml.ledger.api.v1.LedgerConfigurationService", "GetLedgerConfiguration"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new LedgerConfigurationServiceMethodDescriptorSupplier("GetLedgerConfiguration"))
                  .build();
          }
        }
     }
     return getGetLedgerConfigurationMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static LedgerConfigurationServiceStub newStub(io.grpc.Channel channel) {
    return new LedgerConfigurationServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static LedgerConfigurationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new LedgerConfigurationServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static LedgerConfigurationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new LedgerConfigurationServiceFutureStub(channel);
  }

  /**
   * <pre>
   * LedgerConfigurationService allows clients to subscribe to changes of the ledger configuration.
   * </pre>
   */
  public static abstract class LedgerConfigurationServiceImplBase implements io.grpc.BindableService {

    /**
     * <pre>
     * Returns the latest configuration as the first response, and publishes configuration updates in the same stream.
     * Errors:
     * - ``UNAUTHENTICATED``: if the request does not include a valid access token
     * - ``PERMISSION_DENIED``: if the claims in the token are insufficient to perform a given operation
     * - ``NOT_FOUND``: if the request does not include a valid ledger id
     * </pre>
     */
    public void getLedgerConfiguration(com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest request,
        io.grpc.stub.StreamObserver<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getGetLedgerConfigurationMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getGetLedgerConfigurationMethod(),
            asyncServerStreamingCall(
              new MethodHandlers<
                com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest,
                com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse>(
                  this, METHODID_GET_LEDGER_CONFIGURATION)))
          .build();
    }
  }

  /**
   * <pre>
   * LedgerConfigurationService allows clients to subscribe to changes of the ledger configuration.
   * </pre>
   */
  public static final class LedgerConfigurationServiceStub extends io.grpc.stub.AbstractStub<LedgerConfigurationServiceStub> {
    private LedgerConfigurationServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private LedgerConfigurationServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LedgerConfigurationServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new LedgerConfigurationServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     * Returns the latest configuration as the first response, and publishes configuration updates in the same stream.
     * Errors:
     * - ``UNAUTHENTICATED``: if the request does not include a valid access token
     * - ``PERMISSION_DENIED``: if the claims in the token are insufficient to perform a given operation
     * - ``NOT_FOUND``: if the request does not include a valid ledger id
     * </pre>
     */
    public void getLedgerConfiguration(com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest request,
        io.grpc.stub.StreamObserver<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> responseObserver) {
      asyncServerStreamingCall(
          getChannel().newCall(getGetLedgerConfigurationMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * <pre>
   * LedgerConfigurationService allows clients to subscribe to changes of the ledger configuration.
   * </pre>
   */
  public static final class LedgerConfigurationServiceBlockingStub extends io.grpc.stub.AbstractStub<LedgerConfigurationServiceBlockingStub> {
    private LedgerConfigurationServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private LedgerConfigurationServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LedgerConfigurationServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new LedgerConfigurationServiceBlockingStub(channel, callOptions);
    }

    /**
     * <pre>
     * Returns the latest configuration as the first response, and publishes configuration updates in the same stream.
     * Errors:
     * - ``UNAUTHENTICATED``: if the request does not include a valid access token
     * - ``PERMISSION_DENIED``: if the claims in the token are insufficient to perform a given operation
     * - ``NOT_FOUND``: if the request does not include a valid ledger id
     * </pre>
     */
    public java.util.Iterator<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> getLedgerConfiguration(
        com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest request) {
      return blockingServerStreamingCall(
          getChannel(), getGetLedgerConfigurationMethod(), getCallOptions(), request);
    }
  }

  /**
   * <pre>
   * LedgerConfigurationService allows clients to subscribe to changes of the ledger configuration.
   * </pre>
   */
  public static final class LedgerConfigurationServiceFutureStub extends io.grpc.stub.AbstractStub<LedgerConfigurationServiceFutureStub> {
    private LedgerConfigurationServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private LedgerConfigurationServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LedgerConfigurationServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new LedgerConfigurationServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_GET_LEDGER_CONFIGURATION = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final LedgerConfigurationServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(LedgerConfigurationServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_LEDGER_CONFIGURATION:
          serviceImpl.getLedgerConfiguration((com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest) request,
              (io.grpc.stub.StreamObserver<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class LedgerConfigurationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    LedgerConfigurationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("LedgerConfigurationService");
    }
  }

  private static final class LedgerConfigurationServiceFileDescriptorSupplier
      extends LedgerConfigurationServiceBaseDescriptorSupplier {
    LedgerConfigurationServiceFileDescriptorSupplier() {}
  }

  private static final class LedgerConfigurationServiceMethodDescriptorSupplier
      extends LedgerConfigurationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    LedgerConfigurationServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (LedgerConfigurationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new LedgerConfigurationServiceFileDescriptorSupplier())
              .addMethod(getGetLedgerConfigurationMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> bindings-java-2.3.2-sources.jar: com/daml/ledger/api/v1/LedgerConfigurationServiceGrpc.java <==
package com.daml.ledger.api.v1;

import static io.grpc.MethodDescriptor.generateFullMethodName;

/**
 * <pre>
 * LedgerConfigurationService allows clients to subscribe to changes of the ledger configuration.
 * </pre>
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler",
    comments = "Source: com/daml/ledger/api/v1/ledger_configuration_service.proto")
@io.grpc.stub.annotations.GrpcGenerated
public final class LedgerConfigurationServiceGrpc {

  private LedgerConfigurationServiceGrpc() {}

  public static final String SERVICE_NAME = "com.daml.ledger.api.v1.LedgerConfigurationService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest,
      com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> getGetLedgerConfigurationMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetLedgerConfiguration",
      requestType = com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest.class,
      responseType = com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
  public static io.grpc.MethodDescriptor<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest,
      com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> getGetLedgerConfigurationMethod() {
    io.grpc.MethodDescriptor<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest, com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> getGetLedgerConfigurationMethod;
    if ((getGetLedgerConfigurationMethod = LedgerConfigurationServiceGrpc.getGetLedgerConfigurationMethod) == null) {
      synchronized (LedgerConfigurationServiceGrpc.class) {
        if ((getGetLedgerConfigurationMethod = LedgerConfigurationServiceGrpc.getGetLedgerConfigurationMethod) == null) {
          LedgerConfigurationServiceGrpc.getGetLedgerConfigurationMethod = getGetLedgerConfigurationMethod =
              io.grpc.MethodDescriptor.<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest, com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
              .setFullMethodName(generateFullMethodName(SERVICE_NAME, "GetLedgerConfiguration"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse.getDefaultInstance()))
              .setSchemaDescriptor(new LedgerConfigurationServiceMethodDescriptorSupplier("GetLedgerConfiguration"))
              .build();
        }
      }
    }
    return getGetLedgerConfigurationMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static LedgerConfigurationServiceStub newStub(io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<LedgerConfigurationServiceStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<LedgerConfigurationServiceStub>() {
        @java.lang.Override
        public LedgerConfigurationServiceStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new LedgerConfigurationServiceStub(channel, callOptions);
        }
      };
    return LedgerConfigurationServiceStub.newStub(factory, channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static LedgerConfigurationServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<LedgerConfigurationServiceBlockingStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<LedgerConfigurationServiceBlockingStub>() {
        @java.lang.Override
        public LedgerConfigurationServiceBlockingStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new LedgerConfigurationServiceBlockingStub(channel, callOptions);
        }
      };
    return LedgerConfigurationServiceBlockingStub.newStub(factory, channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static LedgerConfigurationServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    io.grpc.stub.AbstractStub.StubFactory<LedgerConfigurationServiceFutureStub> factory =
      new io.grpc.stub.AbstractStub.StubFactory<LedgerConfigurationServiceFutureStub>() {
        @java.lang.Override
        public LedgerConfigurationServiceFutureStub newStub(io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
          return new LedgerConfigurationServiceFutureStub(channel, callOptions);
        }
      };
    return LedgerConfigurationServiceFutureStub.newStub(factory, channel);
  }

  /**
   * <pre>
   * LedgerConfigurationService allows clients to subscribe to changes of the ledger configuration.
   * </pre>
   */
  public static abstract class LedgerConfigurationServiceImplBase implements io.grpc.BindableService {

    /**
     * <pre>
     * Returns the latest configuration as the first response, and publishes configuration updates in the same stream.
     * Errors:
     * - ``UNAUTHENTICATED``: if the request does not include a valid access token
     * - ``PERMISSION_DENIED``: if the claims in the token are insufficient to perform a given operation
     * - ``NOT_FOUND``: if the request does not include a valid ledger id
     * </pre>
     */
    public void getLedgerConfiguration(com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest request,
        io.grpc.stub.StreamObserver<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> responseObserver) {
      io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall(getGetLedgerConfigurationMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getGetLedgerConfigurationMethod(),
            io.grpc.stub.ServerCalls.asyncServerStreamingCall(
              new MethodHandlers<
                com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest,
                com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse>(
                  this, METHODID_GET_LEDGER_CONFIGURATION)))
          .build();
    }
  }

  /**
   * <pre>
   * LedgerConfigurationService allows clients to subscribe to changes of the ledger configuration.
   * </pre>
   */
  public static final class LedgerConfigurationServiceStub extends io.grpc.stub.AbstractAsyncStub<LedgerConfigurationServiceStub> {
    private LedgerConfigurationServiceStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LedgerConfigurationServiceStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new LedgerConfigurationServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     * Returns the latest configuration as the first response, and publishes configuration updates in the same stream.
     * Errors:
     * - ``UNAUTHENTICATED``: if the request does not include a valid access token
     * - ``PERMISSION_DENIED``: if the claims in the token are insufficient to perform a given operation
     * - ``NOT_FOUND``: if the request does not include a valid ledger id
     * </pre>
     */
    public void getLedgerConfiguration(com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest request,
        io.grpc.stub.StreamObserver<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> responseObserver) {
      io.grpc.stub.ClientCalls.asyncServerStreamingCall(
          getChannel().newCall(getGetLedgerConfigurationMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   * <pre>
   * LedgerConfigurationService allows clients to subscribe to changes of the ledger configuration.
   * </pre>
   */
  public static final class LedgerConfigurationServiceBlockingStub extends io.grpc.stub.AbstractBlockingStub<LedgerConfigurationServiceBlockingStub> {
    private LedgerConfigurationServiceBlockingStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LedgerConfigurationServiceBlockingStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new LedgerConfigurationServiceBlockingStub(channel, callOptions);
    }

    /**
     * <pre>
     * Returns the latest configuration as the first response, and publishes configuration updates in the same stream.
     * Errors:
     * - ``UNAUTHENTICATED``: if the request does not include a valid access token
     * - ``PERMISSION_DENIED``: if the claims in the token are insufficient to perform a given operation
     * - ``NOT_FOUND``: if the request does not include a valid ledger id
     * </pre>
     */
    public java.util.Iterator<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse> getLedgerConfiguration(
        com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest request) {
      return io.grpc.stub.ClientCalls.blockingServerStreamingCall(
          getChannel(), getGetLedgerConfigurationMethod(), getCallOptions(), request);
    }
  }

  /**
   * <pre>
   * LedgerConfigurationService allows clients to subscribe to changes of the ledger configuration.
   * </pre>
   */
  public static final class LedgerConfigurationServiceFutureStub extends io.grpc.stub.AbstractFutureStub<LedgerConfigurationServiceFutureStub> {
    private LedgerConfigurationServiceFutureStub(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected LedgerConfigurationServiceFutureStub build(
        io.grpc.Channel channel, io.grpc.CallOptions callOptions) {
      return new LedgerConfigurationServiceFutureStub(channel, callOptions);
    }
  }

  private static final int METHODID_GET_LEDGER_CONFIGURATION = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final LedgerConfigurationServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(LedgerConfigurationServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_LEDGER_CONFIGURATION:
          serviceImpl.getLedgerConfiguration((com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationRequest) request,
              (io.grpc.stub.StreamObserver<com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.GetLedgerConfigurationResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class LedgerConfigurationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    LedgerConfigurationServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return com.daml.ledger.api.v1.LedgerConfigurationServiceOuterClass.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("LedgerConfigurationService");
    }
  }

  private static final class LedgerConfigurationServiceFileDescriptorSupplier
      extends LedgerConfigurationServiceBaseDescriptorSupplier {
    LedgerConfigurationServiceFileDescriptorSupplier() {}
  }

  private static final class LedgerConfigurationServiceMethodDescriptorSupplier
      extends LedgerConfigurationServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    LedgerConfigurationServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (LedgerConfigurationServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new LedgerConfigurationServiceFileDescriptorSupplier())
              .addMethod(getGetLedgerConfigurationMethod())
              .build();
        }
      }
    }
    return result;
  }
}
